@@ -34,6 +34,7 @@ void save_data()
 	int i=0,j, end;
 	double x,y;
 	mw_data val;
+	std::string f_name;
 	ofstream save_file;
 
 	
@@ -48,7 +49,9 @@ void save_data()
 	
 	file_choose_ok->set_label(_("Save"));
 	file_dialog->set_current_folder(datadir);
-	file_dialog->set_current_name("messdaten.dat");
+	f_name = project->filename;
+	if (f_name == "") f_name = "messdaten.dat";
+	file_dialog->set_current_name(f_name);
 	if (!filefilter_dat)
 	{
 		filefilter_dat = Gtk::FileFilter::create();
@@ -164,7 +167,8 @@ void open_datafile()
 			return;
 		}
 		project->datum = read_item("Datum der Messung: ");
-		project->title = read_item("Projekt-Titel: ");		
+		project->title = read_item("Projekt-Titel: ");
+		project->filename = f_name;
 		project->funktion_x = read_item("Messfunktion x: ");
 		project->funktion_y = read_item("Messfunktion y: ");
 		project->unit_x = read_item("Einheit x: ");
@@ -208,7 +212,7 @@ void open_datafile()
 			val.y = get_dbstr (ystr);			
 			new_val(val);			
 		}
-		if ((!is_known_function (project->funktion_x)) || (!is_known_function (project->funktion_x))) translate_functions ();
+		if ((!is_known_function (project->funktion_x)) || (!is_known_function (project->funktion_y))) translate_functions ();
 		if (project->funktion_x != _("Time")) dmm[0].m_funkt = project->funktion_x;
 		dmm[1].m_funkt = project->funktion_y;
 		open_file.close();
