@@ -100,9 +100,13 @@ void eval_data ()
 			diag->funktcol_b = color.get_blue();
 			eval_titvolumen = evaloption_vol->get_state();
 			eval_xreziprok = evaloption_xreziproksw->get_state();
+			check_xreziprok ();
 			eval_yreziprok = evaloption_yreziproksw->get_state();
+			check_yreziprok ();
 			eval_xlog = evaloption_xlogsw->get_state();
+			check_xlog ();
 			eval_ylog = evaloption_ylogsw->get_state();
+			check_ylog ();
 			option = evaloption_xtherm->get_active_text();
 			if (option == "Cu/CuNi") eval_xtherm = CuNi;
 			else if (option == "Ni/NiCr") eval_xtherm = NiCr;
@@ -185,6 +189,99 @@ void show_evaloptions_integration (int page)
 	return;
 }
 
+void check_xlog ()
+{
+	mw_data val;
+	std::string error_str;
+	
+	for (unsigned long long int i=0; i<mi;i++)
+	{
+		val = mw.at(i);
+		if (val.x <= 0)
+		{
+			if (eval_xlog)
+			{
+				error_str = "x -> log x : ";
+				error_str = error_str + _("Operation cannot be executed");
+				fehler (error_str);
+				eval_xlog = false;
+				break;
+			}
+		}
+	}
+	return;
+}
+
+void check_xreziprok ()
+{
+	mw_data val;
+	std::string error_str;
+	
+	for (unsigned long long int i=0; i<mi;i++)
+	{
+		val = mw.at(i);
+		if (val.x == 0)
+		{
+			if (eval_xreziprok)
+			{
+				error_str = "x -> 1/x : ";
+				error_str = error_str + _("Operation cannot be executed");
+				fehler (error_str);
+				eval_xreziprok = false;
+				break;
+			}
+		}
+	}
+	return;
+}
+
+void check_ylog ()
+{
+	mw_data val;
+	std::string error_str;
+	
+	for (unsigned long long int i=0; i<mi;i++)
+	{
+		val = mw.at(i);
+		if (val.y <= 0)
+		{
+			if (eval_ylog)
+			{
+				error_str = "y -> log y : ";
+				error_str = error_str + _("Operation cannot be executed");
+				fehler (error_str);
+				eval_ylog = false;
+				break;
+			}
+		}
+	}
+	return;
+}
+
+void check_yreziprok ()
+{
+	mw_data val;
+	std::string error_str;
+	
+	for (unsigned long long int i=0; i<mi;i++)
+	{
+		val = mw.at(i);
+		if (val.y == 0)
+		{
+			if (eval_yreziprok)
+			{
+				error_str = "y -> 1/y : ";
+				error_str = error_str + _("Operation cannot be executed");
+				fehler (error_str);
+				eval_yreziprok = false;
+				break;
+			}
+		}
+	}
+	return;
+}
+
+
 double trafo_log (double x)
 {
 	double result;
@@ -575,7 +672,10 @@ void find_peaks ()			//find peaks in measurement data
 			// peak-maximum found at center with peak slope > 0
 		{
 			peak.mpos = i;		//position of peak maximum in mw array
-			peak.max.x = - diag->xrange*reg_lin (m_av).a0 / reg_lin (m_av).a1; //maximum corrected by linear regression of slopes
+			peak.max.x = - reg_lin (m_av).a0 / reg_lin (m_av).a1; //maximum corrected by linear regression of slopes
+			if ((peak.max.x < trafo(mw.at(i-1)).x) || (peak.max.x > trafo(mw.at(i+1)).x)) peak.max.x = val.x;
+			// --> in this case correction is not valid
+			peak.max.x *= diag->xrange;
 			gauss = peakreg_gauss (peak.mpos);	// calculate gauss model of peak
 			if (gauss.mpos == i) // regression with gauss model succeeded
 			{
@@ -585,8 +685,9 @@ void find_peaks ()			//find peaks in measurement data
 			{
 				peak.max.y = diag->yrange*val.y;
 			}
-			peak = get_peakarea (peak);	// add baseline value at val.x to min_peakheight
-			if (val.y > (min_peakheight + (yb_a1 * val.x + yb_a0)))		// if < min_peakheight -> forget peak
+			peak = get_peakarea (peak);	
+			// add baseline value at peak.max.x to min_peakheight
+			if (peak.max.y > (min_peakheight + (yb_a1 * peak.max.x + yb_a0)))		// if < min_peakheight -> forget peak
 			{
 				peaks.push_back (peak);
 			}
@@ -664,11 +765,18 @@ peak_data get_peakarea (peak_data peak)
 	for (int k=peak.xb1; k<peak.xb2; k++)
 	{
 		val = trafo(mw.at(k));
+		val.x *= diag->xrange;
+		val.y *= diag->yrange;
 		yb = yb_a1 * val.x + yb_a0;
-		if (k==mi) break; else val2 = trafo(mw.at(k+1));
-		peak.area += (val2.x - val.x) * abs(val.y - yb); // base rectangle
-		peak.area += 0.5*(val2.x - val.x) * abs(val2.y - val.y); // upper triangle
-		peak.area *= diag->yrange;
+		if (k==mi) break; 
+		else 
+		{
+			val2 = trafo(mw.at(k+1));
+			val2.x *= diag->xrange;
+			val2.y *= diag->yrange;
+			peak.area += (val2.x - val.x) * abs(val.y - yb); // base rectangle
+			peak.area += 0.5*(val2.x - val.x) * abs(val2.y - val.y); // upper triangle
+		}
 	}
 	
 	return peak;
@@ -701,7 +809,7 @@ peak_data peakreg_gauss (unsigned long long int max)
 	peak.max.x = - (pc.a1 / (2*pc.a2));		//gauss parameter m is the corrected x-value of maximum
 	peak.max.y = exp (pc.a0 - pow(pc.a1,2) / (4*pc.a2)); //gauss parameter P is the corrected y-value of maximum
 		
-	return peak;	// error bei peaktest max = 23!
+	return peak;
 }
 
 
