@@ -323,6 +323,8 @@ main (int argc, char *argv[])
 	builder->get_widget("diag_symw", diag_symw);
 	builder->get_widget("dmm1_serial_options", dmm_serial_options[0]);
 	builder->get_widget("dmm2_serial_options", dmm_serial_options[1]);
+	builder->get_widget("dmm1_usb_options", dmm_usb_options[0]);
+	builder->get_widget("dmm2_usb_options", dmm_usb_options[1]);
 	builder->get_widget("dmm1_dmm_options", dmm_dmm_options[0]);
 	builder->get_widget("dmm2_dmm_options", dmm_dmm_options[1]);
 	builder->get_widget("dmm2_device_options", dmm_device_options);
@@ -352,6 +354,8 @@ main (int argc, char *argv[])
 	builder->get_widget("dmm2_polling", dmm_polling[1]);
 	builder->get_widget("dmm1_num_bytes", dmm_num_bytes[0]);
 	builder->get_widget("dmm2_num_bytes", dmm_num_bytes[1]);
+	builder->get_widget("dmm1_usb_bytes", dmm_usb_bytes[0]);
+	builder->get_widget("dmm2_usb_bytes", dmm_usb_bytes[1]);
 	builder->get_widget("dmm1_num_val", dmm_num_val[0]);
 	builder->get_widget("dmm2_num_val", dmm_num_val[1]);
 	builder->get_widget("dmm1_timeout", dmm_timeout[0]);
