@@ -56,6 +56,7 @@ Multimeter::Multimeter ()	// DMM with standard values
 	dmm_polling = true;
 	scpi = false;
 	usb = false;
+	usb_bytes = 0;
 	num_bytes = 0;
 	num_val = 1;
 	ms_timeout = 1000;
@@ -143,7 +144,7 @@ void Multimeter::connect_dmm (std::string int_face)
 	{
 		srand (time(NULL));
 		if (auto_slope) m = 0.1 * random_nr (1, 10); // set standard slope 1
-		if (auto_shift) rf = 0.02; // set standard deviation 2% of slope
+		if (auto_shift) rf = 0.03; // set standard deviation 3% of slope
 		if (auto_rt) max_rt = 180; // set maximum retention time for peaks
 		if (auto_bf) bf = 0.005; // set peak width factor
 		if (auto_expshift) exp_rf = 0.01;
@@ -278,6 +279,19 @@ std::string Multimeter::readfrom_dmm ()
         	close(usb_port);
 			return ("");
     	}
+		if (result < usb_bytes) // transmission error? -> repeat reading 
+		{
+			if (dmm_polling) writeto_dmm (poll);
+			result = read(usb_port, buffer, 1024);
+			if (result < usb_bytes)
+			{
+				error_str = _("Transmission error from ") + dmm_name;
+				fehler(error_str);
+				connected = false;
+        		close(usb_port);
+				return ("");
+			}
+		}
     	buffer[result] = '\0';
 		mwert.assign(buffer, result);
 	}
@@ -358,7 +372,7 @@ double Multimeter::sim_linear (double x)
 	sign = random_nr (1,2);
 	if (sign == 2) sign = -1;
 	result = m * x;
-	r = sign * 0.1 * random_nr (1,10) * rf * m; //effective shift in percent
+	r = sign * 0.2 * random_nr (3,10) * rf * m; //effective shift in percent
 	result = result + r;
 	return result;
 }
@@ -1034,6 +1048,25 @@ void Diagramm::find_xy_minmax ()	//find minima and maxima of values
 	return;
 }
 
+double Diagramm::get_scale_element (double scale)  // calculate axis scale element
+{
+	double dxy, exp;
+
+	dxy=scale/10.0;
+	exp = round(log10(dxy));
+	dxy /= pow(10,exp);
+	if (dxy<=0.1) dxy= 0.1;
+	else if (dxy<=0.2) dxy= 0.2;
+	else if (dxy<=0.5) dxy= 0.5;
+	else if (dxy<=1.0) dxy= 1.0;
+	else if (dxy<=2.0) dxy= 2.0;
+	else if (dxy<=5.0) dxy= 5.0;
+	else if (dxy<=10.0) dxy= 10.0;
+	dxy *= pow(10,exp);	
+		
+	return dxy;
+}
+
 
 void Diagramm::set_coord_limits ()		//set limits for coordinate system
 {
@@ -1057,42 +1090,39 @@ void Diagramm::set_coord_limits ()		//set limits for coordinate system
 		ymin -= 1.0;
 	}
 	yscale = ymax - ymin;
-	dy=yscale/10;
-	exp = round(log10(dy));
-	dy /= pow(10,exp);
-	if (dy<0.1) dy= 0.1;
-	else if (dy<0.2) dy= 0.2;
-	else if (dy<0.5) dy= 0.5;
-	else if (dy<1.0) dy= 1.0;
-	else if (dy<2.0) dy= 2.0;
-	else if (dy<5.0) dy= 5.0;
-	else if (dy<10.0) dy= 10.0;
-	dy *= pow(10,exp);
+	dy = get_scale_element (yscale);
 	ymin = floor(ymin/dy)*dy;
-	yscale = 10.0 * dy;
-	ymax = ymin + yscale;
-			
+	ymax = ymin + 10.0 * dy;
+	yscale = ymax - ymin;
+	if (ymax < yrange*ymaxval)
+	{
+		ymax += dy;
+		yscale = ymax - ymin;
+		dy = get_scale_element (yscale);
+		ymin = floor(ymin/dy)*dy;
+		ymax = ymin + 10.0 * dy;
+		yscale = ymax - ymin;
+	}			
 	if (funktion_y == "pH") 
 	{
 		ymin = 0.0;
 		ymax = 14.0;
 		yscale = 14.0;
 	}
-	dx=xscale/10;
-	exp = round(log10(dx));
-	dx /= pow(10,exp);
-	if (dx<0.1) dx= 0.1;
-	else if (dx<0.2) dx= 0.2;
-	else if (dx<0.5) dx= 0.5;
-	else if (dx<1.0) dx= 1.0;
-	else if (dx<2.0) dx= 2.0;
-	else if (dx<5.0) dx= 5.0;
-	else if (dx<10.0) dx= 10.0;
-	dx *= pow(10,exp);
+	dx=get_scale_element (xscale);
 	xscale = 10.0 * dx;
 	xmin = floor(xmin/dx)*dx;
 	xmax = xmin + xscale;
-
+	if (xmax < xrange*xmaxval)
+	{
+		xmax += dx;
+		xscale = xmax - xmin;
+		dx = get_scale_element (xscale);
+		xmin = floor(xmin/dx)*dx;
+		xmax = xmin + 10.0 * dx;
+		xscale = xmax - xmin;
+	}		
+	
 	return;
 }
 
@@ -1554,6 +1584,7 @@ bool Diagramm::on_draw(const Cairo::RefPtr<Cairo::Context> &ccontext)
 {
 	double x,y;
 	mw_data val;
+	m_record xmval, ymval;
 	
 	Gtk::Allocation allocation = get_allocation();
 	diag_width = allocation.get_width();
@@ -1601,11 +1632,9 @@ bool Diagramm::on_draw(const Cairo::RefPtr<Cairo::Context> &ccontext)
 				val = trafo(mw.at(mi-1));
 				x = xrange * val.x;
 				y = yrange * val.y;
-				m_record xmval;
 				xmval.digits = x;
 				xmval.funktion = funktion_x;
 				xmval.unit = unit_x;
-				m_record ymval;
 				ymval.digits = y;
 				ymval.funktion = funktion_y;
 				ymval.unit = unit_y;
@@ -1794,7 +1823,7 @@ void Diagramm::set_unit()
 	}	
 	else
 	{
-		while ((xrange*xabsmax < 0.001) && (xabsmax != 0) && (unit_x.at(0) != 'p'))
+		while ((xrange*xabsmax < 0.1) && (xabsmax != 0) && (unit_x.at(0) != 'p'))
 		{
 			xrange = 1000 * xrange;
 			unit_x = downgrade_unit (unit_x);
@@ -1808,7 +1837,7 @@ void Diagramm::set_unit()
 	//set unit for y values
 	if ((funktion_y != "pH") && (funktion_y != _("Temperature")))
 	{
-		while ((yrange*yabsmax < 0.001) && (yabsmax != 0) && (unit_y.at(0) != 'p'))
+		while ((yrange*yabsmax < 0.1) && (yabsmax != 0) && (unit_y.at(0) != 'p'))
 		{
 			yrange = 1000 * yrange;
 			unit_y = downgrade_unit (unit_y);
@@ -1906,6 +1935,7 @@ void new_project ()
 	datum = std::time(nullptr);
 	project->datum = std::asctime(std::localtime(&datum));
 	project->title = "";
+	project->filename = "";
 	project->comment = "";
 	project->evalresults = "";
 	define_project ();
@@ -2020,6 +2050,7 @@ void define_project ()
     	case(Gtk::RESPONSE_ACCEPT):
     	{
 			project->title = projekt_title->get_text();
+			if ((project->title != "") && (project->filename == "")) project->filename = project->title + ".dat";
 			set_messfunkt (0, func_x->get_active_text());
 			set_messfunkt (1, func_y->get_active_text());
 			project->comment = projekt_comment->get_text();
@@ -2437,7 +2468,7 @@ void end_mess()
 	
 	mw.clear();		// delete values
 	mess_done = false;
-	
+	data_saved = true;
 	return;
 }
 
@@ -2493,19 +2524,23 @@ void get_val()
 void display_mw (m_record xval, m_record yval)
 {
 	std::string mwstring;
-	int pos;
+	int pos, dec;
 
 	mwstring = std::to_string(xval.digits);
+	if (xval.digits != 0) dec = -trunc(log10(abs(xval.digits))) + 4; 
+	else dec = 4;
 	pos = mwstring.find (',');
-	mwstring.resize (pos+5);
+	mwstring.resize (pos+dec);
 	mwstring = "X= " + mwstring + " " + xval.unit;
 	pos = mwstring.find("u");
 	if (pos <= mwstring.length()) mwstring.replace(pos,1,"µ");
 	display_x->set_text (mwstring);
 	display_x->show();
 	mwstring = std::to_string(yval.digits);
+	if (yval.digits != 0) dec = -trunc(log10(abs(yval.digits))) + 4;
+	else dec = 4;
 	pos = mwstring.find (',');
-	mwstring.resize (pos+5);
+	mwstring.resize (pos+dec);
 	mwstring = "Y= " + mwstring + " " + yval.unit;
 	pos = mwstring.find("u");
 	if (pos <= mwstring.length()) mwstring.replace(pos,1,"µ");
