@@ -257,6 +257,7 @@ void show_options_Kanal_XY ()
 			dmm_typ[k]->set_active_text(_("Time"));
 			dmm_dmm_options[k]->hide();
 			dmm_serial_options[k]->hide();
+			dmm_usb_options[k]->hide();
 			dmm_simtyp[k]->hide();
 			dmm_control_options[k]->hide();
 			dmm_function_control[k]->hide();
@@ -293,6 +294,7 @@ void show_options_Kanal_XY ()
 			dmm_polling[k]->set_state(dmm[k].dmm_polling);
 			dmm_scpi[k]->set_state(dmm[k].scpi);
 			dmm_num_bytes[k]->set_value(dmm[k].num_bytes);
+			dmm_usb_bytes[k]->set_value(dmm[k].usb_bytes);
 			dmm_num_val[k]->set_value(dmm[k].num_val);
 			dmm_timeout[k]->set_value(dmm[k].ms_timeout);
 			show_dmm_interface_options (k);
@@ -321,6 +323,7 @@ void show_options_Kanal_XY ()
 		{
 			dmm_dmm_options[k]->hide();
 			dmm_serial_options[k]->hide();
+			dmm_usb_options[k]->hide();
 			dmm_control_options[k]->hide();
 			dmm_function_control[k]->hide();
 			dmm_simtyp[k]->hide();
@@ -343,6 +346,7 @@ void show_options_Kanal_XY ()
 			dmm_dmm_options[k]->hide();
 			dmm_device_options->hide();
 			dmm_serial_options[k]->hide();
+			dmm_usb_options[k]->hide();
 			dmm_control_options[k]->hide();
 			dmm_function_control[k]->hide();
 			switch (dmm[k].dmm_typ)
@@ -612,8 +616,20 @@ void show_dmm_interface_options(int kanal)
 	std::string interface;
 	interface = dmm_interface[kanal]->get_active_text();
 	if (interface.find ("tty")< interface.size())
+	{
 		dmm_serial_options[kanal]->show();
-	else dmm_serial_options[kanal]->hide();
+		dmm_usb_options[kanal]->hide();
+	}
+	else if ((interface.find ("usb")< interface.size()) || (interface.find ("hid")< interface.size()))
+	{
+		dmm_serial_options[kanal]->hide();
+		dmm_usb_options[kanal]->show();
+	}
+	else
+	{
+		dmm_serial_options[kanal]->hide();
+		dmm_usb_options[kanal]->hide();
+	}
 	return;
 }
 
@@ -893,6 +909,7 @@ void set_device_options (int k)	//set options for channel X,Y
 		dmm[k].set_parity (dmm_parity[k]->get_active_text());
 		dmm[k].dmm_polling = dmm_polling[k]->get_state();
 		dmm[k].scpi = dmm_scpi[k]->get_state();
+		dmm[k].usb_bytes = dmm_usb_bytes[k]->get_value();
 		dmm[k].num_bytes = dmm_num_bytes[k]->get_value();
 		dmm[k].num_val = dmm_num_val[k]->get_value();
 		dmm[k].ms_timeout = dmm_timeout[k]->get_value();
@@ -923,6 +940,7 @@ void set_device_options (int k)	//set options for channel X,Y
 		idmm[i].set_parity (dmm_parity[k]->get_active_text());
 		idmm[i].dmm_polling = dmm_polling[k]->get_state();
 		idmm[i].scpi = dmm_scpi[k]->get_state();
+		idmm[i].usb_bytes = dmm_usb_bytes[k]->get_value();
 		idmm[i].num_bytes = dmm_num_bytes[k]->get_value();
 		idmm[i].num_val = dmm_num_val[k]->get_value();
 		idmm[i].ms_timeout = dmm_timeout[k]->get_value();
@@ -1027,7 +1045,7 @@ bool dmm_exist (std::string name) //seek for dmm-name in array of installed dmms
 void select_dmm (int k)
 {
 	int i;
-	std::string name;
+	std::string name, ctrl_str;
 	bool dmm_remote;
 		
 	name = dmm_name[k]->get_active_text ();
@@ -1044,6 +1062,7 @@ void select_dmm (int k)
 			dmm_parity[k]->set_active_text(idmm[i].get_parity());
 			dmm_polling[k]->set_state(idmm[i].dmm_polling);
 			dmm_scpi[k]->set_state(idmm[i].scpi);
+			dmm_usb_bytes[k]->set_value(idmm[i].usb_bytes);
 			dmm_num_bytes[k]->set_value(idmm[i].num_bytes);
 			dmm_num_val[k]->set_value(idmm[i].num_val);
 			dmm_timeout[k]->set_value(idmm[i].ms_timeout);
@@ -1051,24 +1070,75 @@ void select_dmm (int k)
 			dmm_remote = dmm_remote_control[k]->get_state ();
 			if (dmm_remote)
 			{
-				dmm_funktion[k]->set_active_text(idmm[i].m_funkt);
-				dmm_range[k]->set_active_text(idmm[i].m_range);
-				dmm_DCV[k]->set_active_text (idmm[i].get_ctrlstr (DCV));
-				dmm_ACV[k]->set_active_text (idmm[i].get_ctrlstr (ACV));
-				dmm_DCmA[k]->set_active_text (idmm[i].get_ctrlstr (DCmA));
-				dmm_ACmA[k]->set_active_text (idmm[i].get_ctrlstr (ACmA));
-				dmm_DCA[k]->set_active_text (idmm[i].get_ctrlstr (DCA));
-				dmm_ACA[k]->set_active_text (idmm[i].get_ctrlstr (ACA));
-				dmm_Res[k]->set_active_text (idmm[i].get_ctrlstr (Res));
-				dmm_Cond[k]->set_active_text (idmm[i].get_ctrlstr (Cond));
-				dmm_pH[k]->set_active_text (idmm[i].get_ctrlstr (pH));
-				dmm_Temp[k]->set_active_text (idmm[i].get_ctrlstr (Temp));
+				ctrl_str = (idmm[i].m_funkt);
+				dmm_funktion[k]->remove_all();
+				dmm_funktion[k]->append (ctrl_str);
+				dmm_funktion[k]->set_active_text (ctrl_str);
+				
+				ctrl_str = (idmm[i].m_range);
+				dmm_range[k]->remove_all();
+				dmm_range[k]->append (ctrl_str);
+				dmm_range[k]->set_active_text(ctrl_str);
+
+				ctrl_str = (idmm[i].get_ctrlstr (DCV));
+				dmm_DCV[k]->remove_all();
+				dmm_DCV[k]->append (ctrl_str);
+				dmm_DCV[k]->set_active_text (ctrl_str);
+
+				ctrl_str = (idmm[i].get_ctrlstr (ACV));
+				dmm_ACV[k]->remove_all();
+				dmm_ACV[k]->append (ctrl_str);
+				dmm_ACV[k]->set_active_text (ctrl_str);
+
+				ctrl_str = (idmm[i].get_ctrlstr (DCmA));
+				dmm_DCmA[k]->remove_all();
+				dmm_DCmA[k]->append (ctrl_str);
+				dmm_DCmA[k]->set_active_text (ctrl_str);
+
+				ctrl_str = (idmm[i].get_ctrlstr (ACmA));
+				dmm_ACmA[k]->remove_all();
+				dmm_ACmA[k]->append (ctrl_str);
+				dmm_ACmA[k]->set_active_text (ctrl_str);
+
+				ctrl_str = (idmm[i].get_ctrlstr (DCA));
+				dmm_DCA[k]->remove_all();
+				dmm_DCA[k]->append (ctrl_str);
+				dmm_DCA[k]->set_active_text (ctrl_str);
+
+				ctrl_str = (idmm[i].get_ctrlstr (ACA));
+				dmm_ACA[k]->remove_all();
+				dmm_ACA[k]->append (ctrl_str);
+				dmm_ACA[k]->set_active_text (ctrl_str);
+
+				ctrl_str = (idmm[i].get_ctrlstr (Res));
+				dmm_Res[k]->remove_all();
+				dmm_Res[k]->append (ctrl_str);
+				dmm_Res[k]->set_active_text (ctrl_str);
+
+				ctrl_str = (idmm[i].get_ctrlstr (Cond));
+				dmm_Cond[k]->remove_all();
+				dmm_Cond[k]->append (ctrl_str);
+				dmm_Cond[k]->set_active_text (ctrl_str);
+
+				ctrl_str = (idmm[i].get_ctrlstr (pH));
+				dmm_pH[k]->remove_all();
+				dmm_pH[k]->append (ctrl_str);
+				dmm_pH[k]->set_active_text (ctrl_str);
+
+				ctrl_str = (idmm[i].get_ctrlstr (Temp));
+				dmm_Temp[k]->remove_all();
+				dmm_Temp[k]->append (ctrl_str);
+				dmm_Temp[k]->set_active_text (ctrl_str);
+				
 				dmm_control_options[k]->show();
+				show_dmm_function_control (true, k);
 			}
 			else dmm_control_options[k]->hide();
 		}
 	}
-	dmm_serial_options[k]->queue_draw ();	
+	dmm_serial_options[k]->queue_draw ();
+	dmm_usb_options[k]->queue_draw ();
+	show_dmm_interface_options (k);
 	
 	return;
 }
@@ -1134,6 +1204,7 @@ void reset_options_kanal_Y ()
 	dmm[1].dmm_parity = LibSerial::Parity::PARITY_NONE;
 	dmm[1].dmm_polling = true;
 	dmm[1].scpi = false;
+	dmm[1].usb_bytes = 0;
 	dmm[1].num_bytes = 0;
 	dmm[1].num_val = 1;
 	dmm[1].ms_timeout = 100;
@@ -1194,6 +1265,7 @@ void save_dmm_options(int k)
 		dmm_save_file <<"dmm_timeout: " << dmm_timeout[k]->get_value () <<"\n";
 		dmm_save_file <<"dmm_remote_control: " << dmm_remote_control[k]->get_state() <<"\n";
 		dmm_save_file <<"dmm_scpi: " << dmm_scpi[k]->get_state() <<"\n";
+		dmm_save_file <<"dmm_usb_bytes: " << dmm_usb_bytes[k]->get_value_as_int () <<"\n";
 		if (dmm_remote_control[k]->get_state())
 		{
 			dmm_save_file << "DCV: " << dmm_DCV[k]->get_active_text () <<"\n";
@@ -1281,6 +1353,7 @@ void load_dmm_options(int k)
 		dmm_timeout[k]->set_value(get_intstr(read_dmmoption("dmm_timeout: ")));
 		dmm_remote_control[k]->set_state(get_boolstr(read_dmmoption("dmm_remote_control: ")));
 		dmm_scpi[k]->set_state(get_boolstr(read_dmmoption("dmm_scpi: ")));
+		dmm_usb_bytes[k]->set_value(get_intstr(read_dmmoption("dmm_usb_bytes: ")));
 		if (dmm_remote_control[k]->get_state())
 		{
 			ctrl_str = read_dmmoption("DCV: ");
@@ -1315,6 +1388,7 @@ void load_dmm_options(int k)
 			dmm_Temp[k]->set_active_text (ctrl_str);
 		}			
 		dmm_serial_options[k]->queue_draw ();
+		dmm_usb_options[k]->queue_draw ();
 		
 		dmm_open_file.close();
 	}	
@@ -1418,6 +1492,7 @@ void save_all_options ()
 		conf_save_file <<"dmm1_mrange: " << dmm[0].m_range <<"\n";
 		conf_save_file <<"dmm1_remote_control: " << dmm[0].remote_cfg <<"\n";
 		conf_save_file <<"dmm1_scpi: " << dmm[0].scpi <<"\n";
+		conf_save_file <<"dmm1_usb_bytes: " << dmm[0].usb_bytes <<"\n";
 		conf_save_file << "dmm1_DCV: " << dmm[0].get_ctrlstr (DCV) <<"\n";
 		conf_save_file << "dmm1_ACV: " << dmm[0].get_ctrlstr (ACV) <<"\n";
 		conf_save_file << "dmm1_DCmA: " << dmm[0].get_ctrlstr (DCmA) <<"\n";
@@ -1447,6 +1522,7 @@ void save_all_options ()
 		conf_save_file <<"dmm2_mrange: " << dmm[1].m_range <<"\n";
 		conf_save_file <<"dmm2_remote_control: " << dmm[1].remote_cfg <<"\n";
 		conf_save_file <<"dmm2_scpi: " << dmm[1].scpi <<"\n";
+		conf_save_file <<"dmm2_usb_bytes: " << dmm[1].usb_bytes <<"\n";
 		conf_save_file << "dmm2_DCV: " << dmm[1].get_ctrlstr (DCV) <<"\n";
 		conf_save_file << "dmm2_ACV: " << dmm[1].get_ctrlstr (ACV) <<"\n";
 		conf_save_file << "dmm2_DCmA: " << dmm[1].get_ctrlstr (DCmA) <<"\n";
@@ -1543,6 +1619,7 @@ void load_all_options ()
 		dmm[0].m_range = read_option("dmm1_mrange: ");
 		dmm[0].remote_cfg = get_boolstr (read_option ("dmm1_remote_control: " ));
 		dmm[0].scpi = get_boolstr (read_option ("dmm1_scpi: " ));
+		dmm[0].usb_bytes = get_intstr(read_option("dmm1_usb_bytes: "));
 		dmm[0].set_ctrlstr (DCV, read_option("dmm1_DCV: "));
 		dmm_DCV[0]->append (read_option("dmm1_DCV: "));
 		dmm[0].set_ctrlstr (ACV, read_option("dmm1_ACV: "));
@@ -1583,6 +1660,7 @@ void load_all_options ()
 		dmm[1].m_range = read_option("dmm2_mrange: ");
 		dmm[1].remote_cfg = get_boolstr (read_option ("dmm2_remote_control: " ));
 		dmm[1].scpi = get_boolstr (read_option ("dmm2_scpi: " ));
+		dmm[1].usb_bytes = get_intstr(read_option("dmm2_usb_bytes: "));
 		dmm[1].set_ctrlstr (DCV, read_option("dmm2_DCV: "));
 		dmm_DCV[1]->append (read_option("dmm2_DCV: "));
 		dmm[1].set_ctrlstr (ACV, read_option("dmm2_ACV: "));
@@ -1609,6 +1687,9 @@ void load_all_options ()
 		conf_open_file.close();
 	}
 	else fehler (_("Error Reading Configuration File"));
+	if ((!is_known_function (project->funktion_x)) || (!is_known_function (project->funktion_y))) translate_functions ();
+	if (project->funktion_x != _("Time")) dmm[0].m_funkt = project->funktion_x;
+	dmm[1].m_funkt = project->funktion_y;
 	return;
 }
 
@@ -1628,7 +1709,6 @@ std::string read_option(std::string opt_item)
 			break;
 		}
 	}
-	
 	return opt;
 }
 
@@ -1672,7 +1752,6 @@ int get_intstr(std::string num_str)
 	int result;
 	std::string error_str;
 	
-
 	try
 	{
 		result = stoi(num_str);
