@@ -48,6 +48,7 @@ extern Gtk::SpinButton* diag_ymin;
 extern Gtk::SpinButton* diag_ymax;
 extern Gtk::SpinButton* diag_symw;
 extern Gtk::Box* dmm_serial_options[2];
+extern Gtk::Box* dmm_usb_options[2];
 extern Gtk::Box* dmm_dmm_options[2];
 extern Gtk::Box* dmm_device_options;
 extern Gtk::Box* dmm_control_options[2];
@@ -65,6 +66,7 @@ extern Gtk::ComboBoxText* dmm_stopbits[2];
 extern Gtk::ComboBoxText* dmm_parity[2];
 extern Gtk::Switch* dmm_polling[2];
 extern Gtk::SpinButton* dmm_num_bytes[2];
+extern Gtk::SpinButton* dmm_usb_bytes[2];
 extern Gtk::SpinButton* dmm_num_val[2];
 extern Gtk::SpinButton* dmm_timeout[2];
 extern Gtk::ComboBoxText* dmm_funktion[2];
@@ -152,6 +154,8 @@ void load_dmm_options(int k);
 std::string read_dmmoption(std::string opt_item);
 void save_all_options ();
 void load_all_options ();
+void translate_functions ();
+bool is_known_function (std::string funct);
 std::string read_option(std::string opt_item);
 double get_dbstr(std::string num_str);
 int get_intstr(std::string num_str);
