@@ -216,6 +216,7 @@ protected:
 	void draw_selection_frame (double x_1, double y_1, double x_2, double y_2, const Cairo::RefPtr<Cairo::Context> &ct);
 	void find_xy_minmax ();
 	void set_unit();		//select unit prefix and multiply value by appropiate faktor
+	double get_scale_element (double scale);  // calculate axis scale element
 	void set_coord_limits ();
 	double get_xcoord (double xp);
 	double get_ycoord (double yp);
@@ -268,6 +269,7 @@ class Multimeter
 		bool scpi;		// can we communicate by scpi commands?
 		bool usb;		// connect to usb port?
 		int num_bytes;	// number of bytes transmitted
+		int usb_bytes;	// number of bytes transmitted over usb
 		int num_val;	// number of values transmitted 
 		size_t ms_timeout;  // milliseconds
 
@@ -355,6 +357,7 @@ class Messung
 	public:
 		std::string datum;
 		std::string title;
+		std::string filename;
 		std::string funktion_x;
 		std::string funktion_y;	
 		std::string unit_x;
